home · contact · privacy
Redo map system, add map visibility infrastructure.
[plomrogue2-experiments] / client.py
index c9958be1637a9fba9891666444995fbffbbd1589..80cac96aab380849a29c4e54edb6cb5c5bc86579 100755 (executable)
--- a/client.py
+++ b/client.py
@@ -4,43 +4,24 @@ import plom_socket_io
 import socket
 import threading
 from parser import ArgError, Parser
+from game_common import World, Commander
 
 
-class Game:
-    turn = 0
+class Game(Commander):
+    world = World()
     log_text = ''
-    map_size = (5, 5)
-    terrain_map = ('?'*5+'\n')*4+'?'*5
-    things = []
-
-    class Thing:
-        def __init__(self, position, symbol):
-            self.position = position
-            self.symbol = symbol
 
     def log(self, msg):
         """Prefix msg plus newline to self.log_text."""
         self.log_text = msg + '\n' + self.log_text
 
-    def cmd_THING(self, type_, yx):
-        """Add to self.things at .position yx with .symbol defined by type_."""
+    def symbol_for_type(self, type_):
         symbol = '?'
-        if type_ == 'TYPE:human':
+        if type_ == 'human':
             symbol = '@'
-        elif type_ == 'TYPE:monster':
+        elif type_ == 'monster':
             symbol = 'm'
-        self.things += [self.Thing(yx, symbol)]
-    cmd_THING.argtypes = 'string yx_tuple:nonneg'
-
-    def cmd_MAP_SIZE(self, yx):
-        """Set self.map_size to yx, redraw self.terrain_map as '?' cells."""
-        y, x = yx
-        self.map_size = (y, x)
-        self.terrain_map = ''
-        for y in range(self.map_size[0]):
-            self.terrain_map += '?' * self.map_size[1] + '\n'
-        self.terrain_map = self.terrain_map[:-1]
-    cmd_MAP_SIZE.argtypes = 'yx_tuple:nonneg'
+        return symbol
 
     def cmd_TURN_FINISHED(self, n):
         """Do nothing. (This may be extended later.)"""
@@ -49,20 +30,13 @@ class Game:
 
     def cmd_NEW_TURN(self, n):
         """Set self.turn to n, empty self.things."""
-        self.turn = n
-        self.things = []
+        self.world.turn = n
+        self.world.things = []
     cmd_NEW_TURN.argtypes = 'int:nonneg'
 
-    def cmd_TERRAIN(self, terrain_map):
-        """Reset self.terrain_map from terrain_map."""
-        lines = terrain_map.split('\n')
-        if len(lines) != self.map_size[0]:
-            raise ArgError('wrong map height')
-        for line in lines:
-            if len(line) != self.map_size[1]:
-                raise ArgError('wrong map width')
-        self.terrain_map = terrain_map
-    cmd_TERRAIN.argtypes = 'string'
+    def cmd_VISIBLE_MAP_LINE(self, y, terrain_line):
+        self.world.map_.set_line(y, terrain_line)
+    cmd_VISIBLE_MAP_LINE.argtypes = 'int:nonneg string'
 
 
 class WidgetManager:
@@ -80,18 +54,23 @@ class WidgetManager:
         self.top = urwid.Filler(widget_pile, valign='top')
 
     def draw_map(self):
-        """Draw map view from .game.terrain_map, .game.things."""
-        whole_map = []
-        for c in self.game.terrain_map:
-            whole_map += [c]
-        for t in self.game.things:
-            pos_i = t.position[0] * (self.game.map_size[1] + 1) + t.position[1]
-            whole_map[pos_i] = t.symbol
-        return ''.join(whole_map)
+        """Draw map view from .game.map_.terrain, .game.things."""
+        map_lines = []
+        map_size = len(self.game.world.map_.terrain)
+        start_cut = 0
+        while start_cut < map_size:
+            limit = start_cut + self.game.world.map_.size[1]
+            map_lines += [self.game.world.map_.terrain[start_cut:limit]]
+            start_cut = limit
+        for t in self.game.world.things:
+            line_as_list = list(map_lines[t.position[0]])
+            line_as_list[t.position[1]] = self.game.symbol_for_type(t.type_)
+            map_lines[t.position[0]] = ''.join(line_as_list)
+        return "\n".join(map_lines)
 
     def update(self):
         """Redraw all non-edit widgets."""
-        self.turn_widget.set_text('TURN: ' + str(self.game.turn))
+        self.turn_widget.set_text('TURN: ' + str(self.game.world.turn))
         self.log_widget.set_text(self.game.log_text)
         self.map_widget.set_text(self.draw_map())